# Predacons
Predacons is a python library based on transformer used fro transfer learning
## Installation
pip install predacons
## Usage
```python
from predacons import predacons
predacons.rollout()
predacons.read_documents_from_directory()
predacons.clean_text()
predacons.train()
predacons.generate_text()
```
## Contributing
Pull requests are welcome. For major changes, please open an issue first to discuss what you would like to change.
Please make sure to update tests as appropriate.
## License
[MIT](https://choosealicense.com/licenses/mit/)

